Merge pull request #536 from ROCm-Developer-Tools/hotfix_remove_unimplemented_math

Removes use of unimplemented OCML functionality.

[ROCm/hip commit: 525716bf91]
This commit is contained in:
Maneesh Gupta
2018-06-28 11:15:57 +05:30
committed by GitHub
2 changed files with 9 additions and 35 deletions
@@ -508,19 +508,19 @@ inline
float __fadd_rz(float x, float y) { return __ocml_add_rtz_f32(x, y); }
__device__
inline
float __fdiv_rd(float x, float y) { return __ocml_div_rtp_f32(x, y); }
float __fdiv_rd(float x, float y) { return x / y; }
__device__
inline
float __fdiv_rn(float x, float y) { return __ocml_div_rte_f32(x, y); }
float __fdiv_rn(float x, float y) { return x / y; }
__device__
inline
float __fdiv_ru(float x, float y) { return __ocml_div_rtn_f32(x, y); }
float __fdiv_ru(float x, float y) { return x / y; }
__device__
inline
float __fdiv_rz(float x, float y) { return __ocml_div_rtz_f32(x, y); }
float __fdiv_rz(float x, float y) { return x / y; }
__device__
inline
float __fdividef(float x, float y) { return __ocml_div_rte_f32(x, y); }
float __fdividef(float x, float y) { return x / y; }
__device__
inline
float __fmaf_rd(float x, float y, float z)
@@ -1028,16 +1028,16 @@ inline
double __dadd_rz(double x, double y) { return __ocml_add_rtz_f64(x, y); }
__device__
inline
double __ddiv_rd(double x, double y) { return __ocml_div_rtp_f64(x, y); }
double __ddiv_rd(double x, double y) { return x / y; }
__device__
inline
double __ddiv_rn(double x, double y) { return __ocml_div_rte_f64(x, y); }
double __ddiv_rn(double x, double y) { return x / y; }
__device__
inline
double __ddiv_ru(double x, double y) { return __ocml_div_rtn_f64(x, y); }
double __ddiv_ru(double x, double y) { return x / y; }
__device__
inline
double __ddiv_rz(double x, double y) { return __ocml_div_rtz_f64(x, y); }
double __ddiv_rz(double x, double y) { return x / y; }
__device__
inline
double __dmul_rd(double x, double y) { return __ocml_mul_rtp_f64(x, y); }
@@ -69,8 +69,6 @@ float __ocml_cosh_f32(float);
__device__
float __ocml_cospi_f32(float);
__device__
float __ocml_div_rtz_f32(float, float);
__device__
float __ocml_i0_f32(float);
__device__
float __ocml_i1_f32(float);
@@ -290,18 +288,6 @@ __attribute__((const))
float __ocml_mul_rtz_f32(float, float);
__device__
__attribute__((const))
float __ocml_div_rte_f32(float, float);
__device__
__attribute__((const))
float __ocml_div_rtn_f32(float, float);
__device__
__attribute__((const))
float __ocml_div_rtp_f32(float, float);
__device__
__attribute__((const))
float __ocml_div_rtz_f32(float, float);
__device__
__attribute__((const))
float __ocml_sqrt_rte_f32(float);
__device__
__attribute__((const))
@@ -598,18 +584,6 @@ __attribute__((const))
double __ocml_mul_rtz_f64(double, double);
__device__
__attribute__((const))
double __ocml_div_rte_f64(double, double);
__device__
__attribute__((const))
double __ocml_div_rtn_f64(double, double);
__device__
__attribute__((const))
double __ocml_div_rtp_f64(double, double);
__device__
__attribute__((const))
double __ocml_div_rtz_f64(double, double);
__device__
__attribute__((const))
double __ocml_sqrt_rte_f64(double);
__device__
__attribute__((const))